/* Lesson 2 INLINE Code */

----------------------------------------------------------------------
--Lesson 2.3 Create and Implement Indexed Views-----------------------
----------------------------------------------------------------------

-->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>--
USE AdventureWorks2012;
GO
--Set the options to support indexed views.
SET NUMERIC_ROUNDABORT OFF;
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT,
    QUOTED_IDENTIFIER, ANSI_NULLS ON;
GO

-----CREATING AN INDEXED VIEW IN ADVENTUREWROKS2012----
--Create view with schemabinding.
IF OBJECT_ID ('Sales.vOrders', 'view') IS NOT NULL
DROP VIEW Sales.vOrders ;
GO
CREATE VIEW Sales.vOrders
WITH SCHEMABINDING
AS
    SELECT SUM(UnitPrice*OrderQty*(1.00-UnitPriceDiscount)) AS Revenue,
        OrderDate, ProductID, COUNT_BIG(*) AS COUNT
    FROM Sales.SalesOrderDetail AS OD, Sales.SalesOrderHeader AS SOH
    WHERE OD.SalesOrderID = SOH.SalesOrderID
    GROUP BY OrderDate, ProductID;
GO
--Create an index on the view.
CREATE UNIQUE CLUSTERED INDEX IDX_V1 
    ON Sales.vOrders (OrderDate, ProductID);
GO

--This query uses the above indexed view - Sales.vOrders-----------------------
--Use Ctrl-M to set Actual Execution Plan ON-----------------------------------
SELECT  OrderDate, SUM(UnitPrice*OrderQty*(1.00-UnitPriceDiscount)) AS Revenue
FROM Sales.SalesOrderDetail AS OD
    JOIN Sales.SalesOrderHeader AS SOH 
	   ON OD.SalesOrderID=SOH.SalesOrderID
WHERE DATEPART(month,OrderDate)= 5
      AND DATEPART(year,OrderDate) = 2008
GROUP BY OrderDate
ORDER BY OrderDate ASC;
GO

---Delete the view-----------------------------------------------------------
DROP VIEW Sales.vOrders;
GO

-->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>--
----------------------------------------------------------------------
--Lesson 2.5 Use a View to Modify Data--------------------------------
----------------------------------------------------------------------

USE AdventureWorks2012 ; 
GO
UPDATE Sales.vSalesPerson
	SET JobTitle = 'Southwest Sales Manager' 
WHERE LastName = N'Mitchell' AND FirstName = 'Linda'; 
GO

SELECT JobTitle
FROM Sales.vSalesPerson
WHERE LastName = N'Mitchell' AND FirstName = 'Linda'; 
GO

UPDATE Sales.vSalesPerson
	SET JobTitle = 'Sales Representative' 
WHERE LastName = N'Mitchell' AND FirstName = 'Linda'; 
GO

SELECT JobTitle
FROM Sales.vSalesPerson
WHERE LastName = N'Mitchell' AND FirstName = 'Linda'; 
GO
