/* Lesson 7.5 Demo 1 - part 1 Use Data Types for Columns, Keys */

USE CertData;
GO

---------------------------------------------------------------
--Create Schema Sales if it does not already exist --
--Recall, CREATE SCHEMA must be executed in a separate batch --
---------------------------------------------------------------
DECLARE @sql NVARCHAR(255)
SET @sql = 'CREATE SCHEMA Sales'
IF NOT EXISTS (SELECT NAME FROM Sys.Schemas WHERE NAME = 'Sales')
BEGIN
	EXEC sp_executesql @sql 
END;
GO 

-- Creating a table using NEWID as the default value -----------
-- for the uniqueidentifier data type --------------------------
CREATE TABLE Sales.Customers
(
 CustomerID uniqueidentifier NOT NULL
   DEFAULT NEWID(),
 Company varchar(30) NOT NULL,
 ContactName varchar(60) NOT NULL, 
 CountryRegion varchar(20) NOT NULL, 
);
GO

--------------------------------------------------------------------------
--Assign the default value of NEWID() to each new and existing row -------
--This ensures a unique value for the CustomerID column ------------------
INSERT INTO Sales.Customers (CustomerID,Company,ContactName,CountryRegion)
     VALUES
           (NEWID(), N'SQL Studios',N'Mickey', N'CA'),
		   (NEWID(), N'SQL Studios', N'Minnie', N'PA'),
		   (NEWID(), N'SQL Management', N'Donald', N'UK'),
		   (NEWID(), N'SQL Studios', N'Daisy', N'UK'),
		   (NEWID(), N'SQL Management', N'Grumpy', N'WA'),
		   (NEWID(), N'SQL Studios', N'Happy', N'PA'),
		   (NEWID(), N'SQL Management', N'Dopey', N'WA');
GO

SELECT *
FROM Sales.Customers;
GO

-----------------------------------------------------------------------------------
--Using Tempdb, create a table using sequential GUID and nonsequential GUID columns
------------------------------------------------------------------------------------
--Create Unique GUIDs by Using NewSequentialId() and NewId()

USE tempdb
go

---------------------------------------------------------------
--Create table for testing GUID and Identitiy column creation--
--using Identity, NEWSEQUENTIALID(), NEWID()-------------------
---------------------------------------------------------------
CREATE TABLE GUIDTESTING
(
RowNumber			int identity
,NewSequentialIDCol uniqueidentifier DEFAULT NEWSEQUENTIALID()
,NewIdCol			uniqueidentifier DEFAULT NEWID()
);
GO

--------------------------------------------------------------------
-- Insert 5 rows into the GUIDETESTING table using DEFAULT values --
-- as specified by the column datatype ----------------------------- 
DECLARE @RowCount int
SET @RowCount = 0
WHILE @RowCount < 5
BEGIN
	INSERT INTO GUIDTESTING DEFAULT VALUES
	SET @RowCount = @RowCount +1
END;
GO

-- Return the rows sorted by NewSequentialIDCol--
--Notice this sort follows the identity ---------
SELECT * FROM GUIDTESTING ORDER BY NewSequentialIDCol;
GO

-----------------------------------------------
-- Return the rows sorted by NewIDCol----------
SELECT * FROM GUIDTESTING ORDER BY NewIDCol;
GO

