/* Lesson 9.2 Demo 1 - Use FOR XML RAW, FOR XML AUTO, and FOR XML PATH */

USE AdventureWorks2012
GO

SELECT CustomerID
	,SalesOrderID 
	,TerritoryID
	,Convert(Date,OrderDate) AS 'OrderDate'
	,FORMAT(SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.SalesOrderHeader
WHERE CustomerID IN (29825, 29734)
	ORDER BY CustomerID, SalesOrderID;
GO

-->>>>>Results as XML - some fragments and some documents<<<<<<<----
--------------------------------------------------------------------
--Returning Results as XML using SalesOrderHeader table with XMl RAW
--------------------------------------------------------------------
USE AdventureWorks2012
GO

SELECT CustomerID
	,SalesOrderID
	,TerritoryID
	,Convert(Date,OrderDate) AS 'OrderDate'
	,FORMAT(SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.SalesOrderHeader
WHERE CustomerID IN ( 29825, 29734)
	ORDER BY CustomerID, SalesOrderID
FOR XML RAW;
GO

--------------------------------------------------------------------
--Returning Results as XML using SalesOrderHeader table with XML RAW specifying ROOT element Customer
--------------------------------------------------------------------
USE AdventureWorks2012
GO

SELECT CustomerID
	,SalesOrderID
	,TerritoryID
	,Convert(Date,OrderDate) AS 'OrderDate'
	,FORMAT(SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.SalesOrderHeader
WHERE CustomerID IN ( 29825, 29734)
	ORDER BY CustomerID, SalesOrderID
FOR XML RAW, ROOT('CustomerOrders');
GO

--------------------------------------------------------------------
--Returning Results as XML using SalesOrderHeader table with XML AUTO
--------------------------------------------------------------------
USE AdventureWorks2012
GO

SELECT CustomerID
	,SalesOrderID
	,TerritoryID
	,Convert(Date,OrderDate) AS 'OrderDate'
	,FORMAT(SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.SalesOrderHeader
WHERE CustomerID IN ( 29825, 29734)
	ORDER BY CustomerID, SalesOrderID
FOR XML AUTO;
GO

--------------------------------------------------------------------
--Returning Results as XML using SalesOrderHeader table with XML AUTO and ELEMENTS
--------------------------------------------------------------------
USE AdventureWorks2012
GO

SELECT CustomerID
	,SalesOrderID
	,TerritoryID
	,Convert(Date,OrderDate) AS 'OrderDate'
	,FORMAT(SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.SalesOrderHeader
WHERE CustomerID IN ( 29825, 29734)
	ORDER BY CustomerID, SalesOrderID
FOR XML AUTO, ELEMENTS;
GO

-->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------
--Returning Results as XML joining SalesOrderHeader and Customer table using XML RAW
--Selecting both CustomerID and StoreID from Customer table--------------------------
-------------------------------------------------------------------------------------
USE AdventureWorks2012
GO
SELECT Cust.CustomerID, Cust.StoreID 
	,SOH.SalesOrderID 
	,Convert(Date,SOH.OrderDate) AS 'OrderDate'
	,FORMAT(SOH.SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.Customer AS Cust
	INNER JOIN Sales.SalesOrderHeader AS SOH
		ON Cust.CustomerID = SOH.CustomerID
WHERE SOH.CustomerID IN (29825, 29734)
	ORDER BY Cust.CustomerID, SOH.SalesOrderID
FOR XML RAW;
GO

-------------------------------------------------------------------------------------
--Returning Results as XML joining SalesOrderHeader and Customer table using XML RAW
--Selecting both CustomerID and StoreID from Customer table--------------------------
--Enhanced by renaming the row element to 'Order' 
--and specifying top level ROOT element of 'CustomerOrders' 
-------------------------------------------------------------------------------------
USE AdventureWorks2012
GO
SELECT Cust.CustomerID, Cust.StoreID 
	,SOH.SalesOrderID 
	,Convert(Date,SOH.OrderDate) AS 'OrderDate'
	,FORMAT(SOH.SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.Customer AS Cust
	INNER JOIN Sales.SalesOrderHeader AS SOH
		ON Cust.CustomerID = SOH.CustomerID
WHERE SOH.CustomerID IN (29825, 29734)
	ORDER BY Cust.CustomerID, SOH.SalesOrderID
FOR XML RAW('Order'), ROOT('CustomersOrders');
GO


-------------------------------------------------------------------------------------
--Returning Results as XML joining SalesOrderHeader and Customer table using XML AUTO
--Selecting both CustomerID and StoreID from Customer table--------------------------
-------------------------------------------------------------------------------------
USE AdventureWorks2012
GO
SELECT Cust.CustomerID, Cust.StoreID 
	,SOH.SalesOrderID 
	,Convert(Date,SOH.OrderDate) AS 'OrderDate'
	,FORMAT(SOH.SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.Customer AS Cust
	INNER JOIN Sales.SalesOrderHeader AS SOH
		ON Cust.CustomerID = SOH.CustomerID
WHERE SOH.CustomerID IN (29825, 29734)
	ORDER BY Cust.CustomerID, SOH.SalesOrderID
FOR XML AUTO;
GO

-------------------------------------------------------------------------------------
--Returning Results as XML joining SalesOrderHeader and Customer table using XML AUTO
--Selecting both CustomerID and StoreID from Customer table--------------------------
--Specifying top level ROOT element of 'CustomerOrders' -----------------------------
-------------------------------------------------------------------------------------
USE AdventureWorks2012
GO
SELECT Cust.CustomerID, Cust.StoreID 
	,SOH.SalesOrderID 
	,Convert(Date,SOH.OrderDate) AS 'OrderDate'
	,FORMAT(SOH.SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.Customer AS Cust
	INNER JOIN Sales.SalesOrderHeader AS SOH
		ON Cust.CustomerID = SOH.CustomerID
WHERE SOH.CustomerID IN (29825, 29734)
	ORDER BY Cust.CustomerID, SOH.SalesOrderID
FOR XML AUTO, ROOT('CustomersOrders');
GO

-------------------------------------------------------------------------------------
--Returning Results as XML joining SalesOrderHeader and Customer table using XML AUTO
--Selecting both CustomerID and StoreID from Customer table--------------------------
--Specifying top level ROOT element of 'CustomerOrders' -----------------------------
--AND Specifying ELEMENTS lists each attribute on a separate line--------------------
-------------------------------------------------------------------------------------
USE AdventureWorks2012
GO
SELECT Cust.CustomerID, Cust.StoreID 
	,SOH.SalesOrderID 
	,Convert(Date,SOH.OrderDate) AS 'OrderDate'
	,FORMAT(SOH.SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.Customer AS Cust
	INNER JOIN Sales.SalesOrderHeader AS SOH
		ON Cust.CustomerID = SOH.CustomerID
WHERE SOH.CustomerID IN (29825, 29734)
	ORDER BY Cust.CustomerID, SOH.SalesOrderID
FOR XML AUTO, ELEMENTS, ROOT('CustomersOrders');
GO

-------------------------------------------------------------------------------------
--Returning Results as XML joining SalesOrderHeader and Customer table using XML PATH
--Selecting both CustomerID and StoreID from Customer table--------------------------
--Enhanced by renaming the row element to 'Order' 
--and specifying top level ROOT element of 'CustomerOrders' 
-------------------------------------------------------------------------------------
USE AdventureWorks2012
GO
SELECT Cust.CustomerID, Cust.StoreID 
	,SOH.SalesOrderID 
	,Convert(Date,SOH.OrderDate) AS 'OrderDate'
	,FORMAT(SOH.SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.Customer AS Cust
	INNER JOIN Sales.SalesOrderHeader AS SOH
		ON Cust.CustomerID = SOH.CustomerID
WHERE SOH.CustomerID IN (29825, 29734)
	ORDER BY Cust.CustomerID, SOH.SalesOrderID
FOR XML PATH;
GO

-------------------------------------------------------------------------------------
--Returning Results as XML joining SalesOrderHeader and Customer table using XML PATH
--Selecting both CustomerID and StoreID from Customer table--------------------------
--Enhanced by renaming the row element to 'Order' 
--and specifying top level ROOT element of 'CustomerOrders' 
-------------------------------------------------------------------------------------
USE AdventureWorks2012
GO
SELECT Cust.CustomerID, Cust.StoreID 
	,SOH.SalesOrderID 
	,Convert(Date,SOH.OrderDate) AS 'OrderDate'
	,FORMAT(SOH.SubTotal, 'N', 'en-us') AS 'SalesTotal'
FROM Sales.Customer AS Cust
	INNER JOIN Sales.SalesOrderHeader AS SOH
		ON Cust.CustomerID = SOH.CustomerID
WHERE SOH.CustomerID IN (29825, 29734)
	ORDER BY Cust.CustomerID, SOH.SalesOrderID
FOR XML PATH ('Customer'), ROOT('CustomerOrders');
GO